@@ -6,7 +6,7 @@ use std::convert::TryInto;
 use cosmwasm_std::entry_point;
 use cosmwasm_std::{
     to_binary, Addr, Binary, BlockInfo, CustomQuery, Decimal, Deps, DepsMut, Env, MessageInfo,
-    Order, QueryRequest, Reply, StdError, StdResult, Timestamp, WasmMsg,
+    Order, Reply, StdError, StdResult, Timestamp, WasmMsg,
 };
 
 use cw2::{get_contract_version, set_contract_version};
@@ -18,8 +18,7 @@ use semver::Version;
 use tg4::{Member, Tg4Contract};
 use tg_bindings::{
     request_privileges, Ed25519Pubkey, Evidence, EvidenceType, Privilege, PrivilegeChangeMsg,
-    Pubkey, TgradeMsg, TgradeQuery, TgradeSudoMsg, ToAddress, ValidatorDiff, ValidatorUpdate,
-    ValidatorVoteResponse,
+    Pubkey, TgradeMsg, TgradeQuery, TgradeSudoMsg, ValidatorDiff, ValidatorUpdate,
 };
 use tg_utils::{ensure_from_older_version, JailingDuration, SlashMsg, ADMIN};
 
@@ -34,7 +33,7 @@ use crate::msg::{
 use crate::rewards::pay_block_rewards;
 use crate::state::{
     operators, Config, EpochInfo, OperatorInfo, ValidatorInfo, ValidatorSlashing, CONFIG, EPOCH,
-    JAIL, PENDING_VALIDATORS, VALIDATORS, VALIDATOR_SLASHING, VALIDATOR_START_HEIGHT,
+    JAIL, VALIDATORS, VALIDATOR_SLASHING, VALIDATOR_START_HEIGHT,
 };
 
 // version info for migration info
@@ -78,8 +77,6 @@ pub fn instantiate(
         distribution_contracts,
         // Will be overwritten in reply for rewards contract instantiation
         validator_group: Addr::unchecked(""),
-        verify_validators: msg.verify_validators,
-        offline_jail_duration: msg.offline_jail_duration,
     };
     CONFIG.save(deps.storage, &cfg)?;
 
@@ -649,7 +646,7 @@ fn is_genesis_block(block: &BlockInfo) -> bool {
     block.height < 2
 }
 
-fn end_block(deps: DepsMut<TgradeQuery>, env: Env) -> Result<Response, ContractError> {
+fn end_block<Q: CustomQuery>(deps: DepsMut<Q>, env: Env) -> Result<Response, ContractError> {
     let cfg = CONFIG.load(deps.storage)?;
 
     // check if needed and quit early if we didn't hit epoch boundary
@@ -670,31 +667,8 @@ fn end_block(deps: DepsMut<TgradeQuery>, env: Env) -> Result<Response, ContractE
     epoch.current_epoch = cur_epoch;
     EPOCH.save(deps.storage, &epoch)?;
 
-    if cfg.verify_validators {
-        let votes = deps
-            .querier
-            .query::<ValidatorVoteResponse>(&QueryRequest::Custom(TgradeQuery::ValidatorVotes {}))?
-            .votes;
-
-        if let Some(pending) = PENDING_VALIDATORS.may_load(deps.storage)? {
-            let expiration = JailingPeriod::from_duration(
-                JailingDuration::Duration(cfg.offline_jail_duration),
-                &env.block,
-            );
-
-            for val in pending {
-                let vote = votes
-                    .iter()
-                    .find(|vote| vote.address.as_slice() == val.1.to_address());
-                if vote.is_none() || !vote.unwrap().voted {
-                    JAIL.save(deps.storage, &val.0, &expiration)?;
-                }
-            }
-        }
-    }
-
     // calculate and store new validator set
-    let (mut validators, auto_unjail) = calculate_validators(deps.as_ref(), &env)?;
+    let (validators, auto_unjail) = calculate_validators(deps.as_ref(), &env)?;
 
     // auto unjailing
     for addr in &auto_unjail {
@@ -703,41 +677,14 @@ fn end_block(deps: DepsMut<TgradeQuery>, env: Env) -> Result<Response, ContractE
 
     let old_validators = VALIDATORS.load(deps.storage)?;
 
+    VALIDATORS.save(deps.storage, &validators)?;
     // determine the diff to send back to tendermint
-    let (diff, add, remove) = calculate_diff(validators.clone(), old_validators);
+    let (diff, add, remove) = calculate_diff(validators, old_validators);
     let update_members = RewardsDistribution::UpdateMembers {
         add: add.clone(),
         remove: remove.clone(),
     };
 
-    if cfg.verify_validators {
-        // pending validators are validators who have just been added and have yet to verify they're online
-        // and signing blocks (or at least signing the first one)
-        let pending: Vec<_> = add
-            .iter()
-            .filter_map(|m| {
-                let addr = Addr::unchecked(&m.addr);
-                if let Ok(op) = operators().load(deps.storage, &addr) {
-                    if !op.active_validator {
-                        Some((addr, op.pubkey))
-                    } else {
-                        None
-                    }
-                } else {
-                    None
-                }
-            })
-            .collect();
-        PENDING_VALIDATORS.save(deps.storage, &pending)?;
-        for v in &mut validators {
-            if pending.iter().any(|(addr, _)| *addr == v.operator) {
-                v.power = cfg.min_points;
-            }
-        }
-    }
-
-    VALIDATORS.save(deps.storage, &validators)?;
-
     // update operators list with info about whether or not they're active validators
     for op in add {
         operators().update::<_, StdError>(deps.storage, &Addr::unchecked(op.addr), |op| {
@@ -1008,8 +955,8 @@ mod evidence {
 
 /// If some validators are caught on malicious behavior (for example double signing),
 /// they are reported and punished on begin of next block.
-fn begin_block(
-    mut deps: DepsMut<TgradeQuery>,
+fn begin_block<Q: CustomQuery>(
+    mut deps: DepsMut<Q>,
     env: Env,
     evidences: Vec<Evidence>,
 ) -> Result<Response, ContractError> {
