@@ -5,7 +5,7 @@ use std::ops::Add;
 
 use tg4::Member;
 use tg_bindings::{Ed25519Pubkey, Pubkey};
-use tg_utils::{Duration, Expiration, JailingDuration};
+use tg_utils::{Expiration, JailingDuration};
 
 use crate::error::ContractError;
 use crate::state::{DistributionContract, OperatorInfo, ValidatorInfo, ValidatorSlashing};
@@ -90,17 +90,6 @@ pub struct InstantiateMsg {
     ///
     /// This contract has to support all the `RewardsDistribution` messages
     pub validator_group_code_id: u64,
-
-    /// When a validator joins the valset, verify they sign the first block since joining
-    /// or jail them for a period otherwise.
-    ///
-    /// The verification happens every time the validator becomes an active validator,
-    /// including when they are unjailed or when they just gain enough power to participate.
-    pub verify_validators: bool,
-
-    /// The duration to jail a validator for in case they don't sign their first epoch
-    /// boundary block. After the period, they have to pass verification again, ad infinitum.
-    pub offline_jail_duration: Duration,
 }
 
 impl InstantiateMsg {
@@ -543,8 +532,6 @@ mod test {
             double_sign_slash_ratio: Decimal::percent(50),
             distribution_contracts: UnvalidatedDistributionContracts::default(),
             validator_group_code_id: 0,
-            verify_validators: false,
-            offline_jail_duration: Duration::new(0),
         };
         proper.validate().unwrap();
 
