@@ -9,7 +9,7 @@ use cosmwasm_std::{
 use cw_multi_test::{next_block, AppResponse, Contract, ContractWrapper, CosmosRouter, Executor};
 use derivative::Derivative;
 use tg4::{AdminResponse, Member};
-use tg_bindings::{Evidence, Pubkey, TgradeMsg, TgradeQuery, ValidatorDiff, ValidatorVote};
+use tg_bindings::{Evidence, Pubkey, TgradeMsg, TgradeQuery, ValidatorDiff};
 use tg_bindings_test::TgradeApp;
 use tg_utils::{Duration, JailingDuration};
 
@@ -100,7 +100,6 @@ pub struct SuiteBuilder {
     distribution_configs: Vec<DistributionConfig>,
     /// Funds to add on init per address
     init_funds: Vec<(String, Vec<Coin>)>,
-    verify_validators: Option<Duration>,
 }
 
 impl SuiteBuilder {
@@ -165,11 +164,6 @@ impl SuiteBuilder {
         self
     }
 
-    pub fn with_verify_validators(mut self, duration: u64) -> Self {
-        self.verify_validators = Some(Duration::new(duration));
-        self
-    }
-
     pub fn with_epoch_reward(mut self, epoch_reward: Coin) -> Self {
         self.epoch_reward = epoch_reward;
         self
@@ -353,10 +347,6 @@ impl SuiteBuilder {
                         inner: distribution_contract_instantiation_info,
                     },
                     validator_group_code_id: engagement_id,
-                    verify_validators: self.verify_validators.is_some(),
-                    offline_jail_duration: self
-                        .verify_validators
-                        .unwrap_or_else(|| Duration::new(0)),
                 },
                 &[],
                 "valset",
@@ -802,12 +792,4 @@ impl Suite {
             self.valset_code_id,
         )
     }
-
-    pub fn set_votes(&mut self, votes: &[ValidatorVote]) -> AnyResult<()> {
-        Ok(self
-            .app
-            .init_modules(|router, _api, storage| -> StdResult<()> {
-                router.custom.set_votes(storage, votes.to_vec())
-            })?)
-    }
 }
